@@ -38,34 +38,35 @@
 #'
 #' @export
 DoubleDensityPlot <- function(frame, xvar, truthVar, title,...) {
-  frame <- check_frame_args_list(...,
-                                 frame = frame,
-                                 name_var_list = list(xvar = xvar, truthVar = truthVar),
-                                 title = title,
-                                 funname = "WVPlots::DoubleDensityPlot")
+  frame <- as.data.frame(frame)
+  check_frame_args_list(...,
+                        frame = frame,
+                        name_var_list = list(xvar = xvar, truthVar = truthVar),
+                        title = title,
+                        funname = "WVPlots::DoubleDensityPlot")
   df <- data.frame(x=as.numeric(frame[[xvar]]),
                    y=as.character(frame[[truthVar]]),
                    stringsAsFactors=FALSE)
   pf <- wv_gapply(df,'y',
-                    partitionMethod='split',
-                    function(sf) {
-                      uvals <- unique(sf[['x']])
-                      nunique <- length(uvals)
-                      if(nunique>1) {
-                        dens <- density(sf[['x']],adjust=0.5,
-                                        from=min(sf[['x']]),to=max(sf[['x']]))
-                        rf <- data.frame(density=dens$y,xintercept=NA,
-                                         stringsAsFactors=FALSE)
-                        rf[[xvar]] <- dens$x
-                        rf[[truthVar]] <- sf$y[[1]]
-                      } else {
-                        rf <- data.frame(density=NA,xintercept=uvals,
-                                         stringsAsFactors=FALSE)
-                        rf[[xvar]] <- NA
-                        rf[[truthVar]] <- sf$y[[1]]
-                      }
-                      rf
-                    })
+                  partitionMethod='split',
+                  function(sf) {
+                    uvals <- unique(sf[['x']])
+                    nunique <- length(uvals)
+                    if(nunique>1) {
+                      dens <- density(sf[['x']],adjust=0.5,
+                                      from=min(sf[['x']]),to=max(sf[['x']]))
+                      rf <- data.frame(density=dens$y,xintercept=NA,
+                                       stringsAsFactors=FALSE)
+                      rf[[xvar]] <- dens$x
+                      rf[[truthVar]] <- sf$y[[1]]
+                    } else {
+                      rf <- data.frame(density=NA,xintercept=uvals,
+                                       stringsAsFactors=FALSE)
+                      rf[[xvar]] <- NA
+                      rf[[truthVar]] <- sf$y[[1]]
+                    }
+                    rf
+                  })
   pf$zero = 0
   # library(RColorBrewer)
   # display.brewer.all()
@@ -75,7 +76,7 @@ DoubleDensityPlot <- function(frame, xvar, truthVar, title,...) {
                                                      ymin='zero',ymax='density',
                                                      color=truthVar,fill=truthVar,
                                                      linetype=truthVar
-                                                     ))
+                         ))
   if(sum(!is.na(pf$density))>0) {
     plt <- plt + ggplot2::geom_line() +
       ggplot2::geom_ribbon(alpha=0.5,color=NA)
